summaryrefslogtreecommitdiffhomepage
path: root/examples/physics
diff options
context:
space:
mode:
authorRay <[email protected]>2021-01-20 20:55:12 +0100
committerRay <[email protected]>2021-01-20 20:55:12 +0100
commit677f420bf00d346b8b5a84ac17beaf70111dbf2b (patch)
treea24f30ac0149a6d043715c674f9a7bfae4584664 /examples/physics
parentb845f3886a24db69c25fd685d99cad00200e79f1 (diff)
downloadraylib-677f420bf00d346b8b5a84ac17beaf70111dbf2b.tar.gz
raylib-677f420bf00d346b8b5a84ac17beaf70111dbf2b.zip
REVIEWED: physac module and examples #1525
Diffstat (limited to 'examples/physics')
-rw-r--r--examples/physics/physics_demo.c34
-rw-r--r--examples/physics/physics_friction.c21
-rw-r--r--examples/physics/physics_movement.c21
-rw-r--r--examples/physics/physics_restitution.c22
-rw-r--r--examples/physics/physics_shatter.c38
5 files changed, 47 insertions, 89 deletions
diff --git a/examples/physics/physics_shatter.c b/examples/physics/physics_shatter.c
index cbc65221..46876ff7 100644
--- a/examples/physics/physics_shatter.c
+++ b/examples/physics/physics_shatter.c
@@ -1,24 +1,19 @@
/*******************************************************************************************
*
-* Physac - Body shatter
+* raylib [physac] example - physics shatter
*
-* NOTE 1: Physac requires multi-threading, when InitPhysics() a second thread is created to manage physics calculations.
-* NOTE 2: Physac requires static C library linkage to avoid dependency on MinGW DLL (-static -lpthread)
+* This example has been created using raylib 1.5 (www.raylib.com)
+* raylib is licensed under an unmodified zlib/libpng license (View raylib.h for details)
*
-* Use the following line to compile:
+* This example uses physac 1.1 (https://github.com/raysan5/raylib/blob/master/src/physac.h)
*
-* gcc -o $(NAME_PART).exe $(FILE_NAME) -s -static /
-* -lraylib -lpthread -lglfw3 -lopengl32 -lgdi32 -lopenal32 -lwinmm /
-* -std=c99 -Wl,--subsystem,windows -Wl,-allow-multiple-definition
-*
-* Copyright (c) 2016-2018 Victor Fisac
+* Copyright (c) 2016-2021 Victor Fisac (@victorfisac) and Ramon Santamaria (@raysan5)
*
********************************************************************************************/
#include "raylib.h"
#define PHYSAC_IMPLEMENTATION
-#define PHYSAC_NO_THREADS
#include "physac.h"
int main(void)
@@ -29,12 +24,11 @@ int main(void)
const int screenHeight = 450;
SetConfigFlags(FLAG_MSAA_4X_HINT);
- InitWindow(screenWidth, screenHeight, "Physac [raylib] - Body shatter");
+ InitWindow(screenWidth, screenHeight, "raylib [physac] example - physics shatter");
// Physac logo drawing position
int logoX = screenWidth - MeasureText("Physac", 30) - 10;
int logoY = 15;
- bool needsReset = false;
// Initialize physics and default physics bodies
InitPhysics();
@@ -49,31 +43,23 @@ int main(void)
// Main game loop
while (!WindowShouldClose()) // Detect window close button or ESC key
{
- // Update
- RunPhysicsStep();
-
//----------------------------------------------------------------------------------
- // Delay initialization of variables due to physics reset asynchronous
- if (needsReset)
- {
- // Create random polygon physics body to shatter
- CreatePhysicsBodyPolygon((Vector2){ screenWidth/2, screenHeight/2 }, GetRandomValue(80, 200), GetRandomValue(3, 8), 10);
- needsReset = false;
- }
-
- if (IsKeyPressed('R')) // Reset physics input
+ UpdatePhysics(); // Update physics system
+
+ if (IsKeyPressed('R')) // Reset physics input
{
ResetPhysics();
- needsReset = true;
+
+ CreatePhysicsBodyPolygon((Vector2){ screenWidth/2, screenHeight/2 }, GetRandomValue(80, 200), GetRandomValue(3, 8), 10);
}
if (IsMouseButtonPressed(MOUSE_LEFT_BUTTON)) // Physics shatter input
{
- // Note: some values need to be stored in variables due to asynchronous changes during main thread
int count = GetPhysicsBodiesCount();
for (int i = count - 1; i >= 0; i--)
{
PhysicsBody currentBody = GetPhysicsBody(i);
+
if (currentBody != NULL) PhysicsShatter(currentBody, GetMousePosition(), 10/currentBody->inverseMass);
}
}
diff --git a/examples/physics/physics_demo.c b/examples/physics/physics_demo.c
index 421c82a9..9763bf99 100644
--- a/examples/physics/physics_demo.c
+++ b/examples/physics/physics_demo.c
@@ -1,24 +1,19 @@
/*******************************************************************************************
*
* Physac - Physics demo
*
-* NOTE 1: Physac requires multi-threading, when InitPhysics() a second thread is created to manage physics calculations.
-* NOTE 2: Physac requires static C library linkage to avoid dependency on MinGW DLL (-static -lpthread)
+* This example has been created using raylib 1.5 (www.raylib.com)
+* raylib is licensed under an unmodified zlib/libpng license (View raylib.h for details)
*
-* Use the following line to compile:
+* This example uses physac 1.1 (https://github.com/raysan5/raylib/blob/master/src/physac.h)
*
-* gcc -o $(NAME_PART).exe $(FILE_NAME) -s -static /
-* -lraylib -lpthread -lglfw3 -lopengl32 -lgdi32 -lopenal32 -lwinmm /
-* -std=c99 -Wl,--subsystem,windows -Wl,-allow-multiple-definition
-*
-* Copyright (c) 2016-2018 Victor Fisac
+* Copyright (c) 2016-2021 Victor Fisac (@victorfisac) and Ramon Santamaria (@raysan5)
*
********************************************************************************************/
#include "raylib.h"
#define PHYSAC_IMPLEMENTATION
-#define PHYSAC_NO_THREADS
#include "physac.h"
int main(void)
@@ -29,12 +24,11 @@ int main(void)
const int screenHeight = 450;
SetConfigFlags(FLAG_MSAA_4X_HINT);
- InitWindow(screenWidth, screenHeight, "Physac [raylib] - Physics demo");
+ InitWindow(screenWidth, screenHeight, "raylib [physac] example - physics demo");
// Physac logo drawing position
int logoX = screenWidth - MeasureText("Physac", 30) - 10;
int logoY = 15;
- bool needsReset = false;
// Initialize physics and default physics bodies
InitPhysics();
@@ -55,25 +49,17 @@ int main(void)
{
// Update
//----------------------------------------------------------------------------------
- // Delay initialization of variables due to physics reset async
- RunPhysicsStep();
+ UpdatePhysics(); // Update physics system
- if (needsReset)
+ if (IsKeyPressed('R')) // Reset physics system
{
+ ResetPhysics();
+
floor = CreatePhysicsBodyRectangle((Vector2){ screenWidth/2, screenHeight }, 500, 100, 10);
floor->enabled = false;
circle = CreatePhysicsBodyCircle((Vector2){ screenWidth/2, screenHeight/2 }, 45, 10);
circle->enabled = false;
-
- needsReset = false;
- }
-
- // Reset physics input
- if (IsKeyPressed('R'))
- {
- ResetPhysics();
- needsReset = true;
}
// Physics body creation inputs
@@ -1,24 +1,19 @@
/*******************************************************************************************
*
-* Physac - Physics demo
+* raylib [physac] example - physics demo
*
diff --git a/examples/physics/physics_friction.c b/examples/physics/physics_friction.c
index 0acf88ae..b9195039 100644
--- a/examples/physics/physics_friction.c
+++ b/examples/physics/physics_friction.c
@@ -1,24 +1,19 @@
/*******************************************************************************************
*
* Physac - Physics friction
*
-* NOTE 1: Physac requires multi-threading, when InitPhysics() a second thread is created to manage physics calculations.
-* NOTE 2: Physac requires static C library linkage to avoid dependency on MinGW DLL (-static -lpthread)
+* This example has been created using raylib 1.5 (www.raylib.com)
+* raylib is licensed under an unmodified zlib/libpng license (View raylib.h for details)
*
-* Use the following line to compile:
+* This example uses physac 1.1 (https://github.com/raysan5/raylib/blob/master/src/physac.h)
*
-* gcc -o $(NAME_PART).exe $(FILE_NAME) -s -static /
-* -lraylib -lpthread -lglfw3 -lopengl32 -lgdi32 -lopenal32 -lwinmm /
-* -std=c99 -Wl,--subsystem,windows -Wl,-allow-multiple-definition
-*
-* Copyright (c) 2016-2018 Victor Fisac
+* Copyright (c) 2016-2021 Victor Fisac (@victorfisac) and Ramon Santamaria (@raysan5)
*
********************************************************************************************/
#include "raylib.h"
#define PHYSAC_IMPLEMENTATION
-#define PHYSAC_NO_THREADS
#include "physac.h"
int main(void)
@@ -29,7 +24,7 @@ int main(void)
const int screenHeight = 450;
SetConfigFlags(FLAG_MSAA_4X_HINT);
- InitWindow(screenWidth, screenHeight, "Physac [raylib] - Physics friction");
+ InitWindow(screenWidth, screenHeight, "raylib [physac] example - physics friction");
// Physac logo drawing position
int logoX = screenWidth - MeasureText("Physac", 30) - 10;
@@ -73,9 +68,9 @@ int main(void)
{
// Update
//----------------------------------------------------------------------------------
- RunPhysicsStep();
+ UpdatePhysics(); // Update physics system
- if (IsKeyPressed('R')) // Reset physics input
+ if (IsKeyPressed('R')) // Reset physics system
{
// Reset dynamic physics bodies position, velocity and rotation
bodyA->position = (Vector2){ 35, screenHeight*0.6f };
@@ -1,24 +1,19 @@
/*******************************************************************************************
*
-* Physac - Physics friction
+* raylib [physac] example - physics friction
*
diff --git a/examples/physics/physics_movement.c b/examples/physics/physics_movement.c
index d946811d..73a1f927 100644
--- a/examples/physics/physics_movement.c
+++ b/examples/physics/physics_movement.c
@@ -1,24 +1,19 @@
/*******************************************************************************************
*
* Physac - Physics movement
*
-* NOTE 1: Physac requires multi-threading, when InitPhysics() a second thread is created to manage physics calculations.
-* NOTE 2: Physac requires static C library linkage to avoid dependency on MinGW DLL (-static -lpthread)
+* This example has been created using raylib 1.5 (www.raylib.com)
+* raylib is licensed under an unmodified zlib/libpng license (View raylib.h for details)
*
-* Use the following line to compile:
+* This example uses physac 1.1 (https://github.com/raysan5/raylib/blob/master/src/physac.h)
*
-* gcc -o $(NAME_PART).exe $(FILE_NAME) -s -static /
-* -lraylib -lpthread -lglfw3 -lopengl32 -lgdi32 -lopenal32 -lwinmm /
-* -std=c99 -Wl,--subsystem,windows -Wl,-allow-multiple-definition
-*
-* Copyright (c) 2016-2018 Victor Fisac
+* Copyright (c) 2016-2021 Victor Fisac (@victorfisac) and Ramon Santamaria (@raysan5)
*
********************************************************************************************/
#include "raylib.h"
#define PHYSAC_IMPLEMENTATION
-#define PHYSAC_NO_THREADS
#include "physac.h"
#define VELOCITY 0.5f
@@ -31,7 +26,7 @@ int main(void)
const int screenHeight = 450;
SetConfigFlags(FLAG_MSAA_4X_HINT);
- InitWindow(screenWidth, screenHeight, "Physac [raylib] - Physics movement");
+ InitWindow(screenWidth, screenHeight, "raylib [physac] example - physics movement");
// Physac logo drawing position
int logoX = screenWidth - MeasureText("Physac", 30) - 10;
@@ -66,9 +61,9 @@ int main(void)
{
// Update
//----------------------------------------------------------------------------------
- RunPhysicsStep();
+ UpdatePhysics(); // Update physics system
- if (IsKeyPressed('R')) // Reset physics input
+ if (IsKeyPressed('R')) // Reset physics input
{
// Reset movement physics body position, velocity and rotation
body->position = (Vector2){ screenWidth/2, screenHeight/2 };
@@ -1,24 +1,19 @@
/*******************************************************************************************
*
-* Physac - Physics movement
+* raylib [physac] example - physics movement
*
diff --git a/examples/physics/physics_restitution.c b/examples/physics/physics_restitution.c
index 12a2a922..787db98d 100644
--- a/examples/physics/physics_restitution.c
+++ b/examples/physics/physics_restitution.c
@@ -1,24 +1,19 @@
/*******************************************************************************************
*
* Physac - Physics restitution
*
-* NOTE 1: Physac requires multi-threading, when InitPhysics() a second thread is created to manage physics calculations.
-* NOTE 2: Physac requires static C library linkage to avoid dependency on MinGW DLL (-static -lpthread)
+* This example has been created using raylib 1.5 (www.raylib.com)
+* raylib is licensed under an unmodified zlib/libpng license (View raylib.h for details)
*
-* Use the following line to compile:
+* This example uses physac 1.1 (https://github.com/raysan5/raylib/blob/master/src/physac.h)
*
-* gcc -o $(NAME_PART).exe $(FILE_NAME) -s -static /
-* -lraylib -lpthread -lglfw3 -lopengl32 -lgdi32 -lopenal32 -lwinmm /
-* -std=c99 -Wl,--subsystem,windows -Wl,-allow-multiple-definition
-*
-* Copyright (c) 2016-2018 Victor Fisac
+* Copyright (c) 2016-2021 Victor Fisac (@victorfisac) and Ramon Santamaria (@raysan5)
*
********************************************************************************************/
#include "raylib.h"
#define PHYSAC_IMPLEMENTATION
-#define PHYSAC_NO_THREADS
#include "physac.h"
int main(void)
@@ -29,7 +24,7 @@ int main(void)
const int screenHeight = 450;
SetConfigFlags(FLAG_MSAA_4X_HINT);
- InitWindow(screenWidth, screenHeight, "Physac [raylib] - Physics restitution");
+ InitWindow(screenWidth, screenHeight, "raylib [physac] example - physics restitution");
// Physac logo drawing position
int logoX = screenWidth - MeasureText("Physac", 30) - 10;
@@ -62,9 +57,9 @@ int main(void)
{
// Update
//----------------------------------------------------------------------------------
- RunPhysicsStep();
+ UpdatePhysics(); // Update physics system
- if (IsKeyPressed('R')) // Reset physics input
+ if (IsKeyPressed('R')) // Reset physics input
{
// Reset circles physics bodies position and velocity
circleA->position = (Vector2){ screenWidth*0.25f, screenHeight/2 };
@@ -124,6 +119,7 @@ int main(void)
DestroyPhysicsBody(circleB);
DestroyPhysicsBody(circleC);
DestroyPhysicsBody(floor);
+
ClosePhysics(); // Unitialize physics
CloseWindow(); // Close window and OpenGL context
@@ -1,24 +1,19 @@
/*******************************************************************************************
*
-* Physac - Physics restitution
+* raylib [physac] example - physics restitution
*